==> kdeutils-4.1.1.tar.bz2: kdeutils-4.1.1/okteta/program/oktetakakao/controllers/view/print/printcontroller.cpp <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2007-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "printcontroller.h"

// controller
#include "printtool.h"
// KDE
#include <KXmlGuiWindow>
#include <KActionCollection>
#include <KStandardAction>
#include <KAction>


PrintController::PrintController( KXmlGuiWindow *window )
 : mPrintTool( new PrintTool() )
{
    KActionCollection *actionCollection = window->actionCollection();

    mPrintAction = KStandardAction::print( mPrintTool, SLOT(print()), actionCollection );
    connect( mPrintTool, SIGNAL(viewChanged( bool )),
             mPrintAction, SLOT(setEnabled( bool )) );

    setView( 0 );
}

void PrintController::setView( KAbstractView *view )
{
    mPrintTool->setView( view );
}


PrintController::~PrintController()
{
    delete mPrintTool;
}

==> kdeutils-4.3.0.tar.bz2: kdeutils-4.3.0/okteta/program/oktetakakao/controllers/view/print/printcontroller.cpp <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2007-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "printcontroller.h"

// controller
#include "printtool.h"
// KDE
#include <KXMLGUIClient>
#include <KActionCollection>
#include <KStandardAction>
#include <KAction>


PrintController::PrintController( KXMLGUIClient* guiClient )
 : mPrintTool( new PrintTool() )
{
    KActionCollection* actionCollection = guiClient->actionCollection();

    mPrintAction = KStandardAction::print( mPrintTool, SLOT(print()), actionCollection );
    connect( mPrintTool, SIGNAL(viewChanged( bool )),
             mPrintAction, SLOT(setEnabled( bool )) );

    setTargetModel( 0 );
}

void PrintController::setTargetModel( AbstractModel* model )
{
    mPrintTool->setTargetModel( model );
}


PrintController::~PrintController()
{
    delete mPrintTool;
}
